% In questo M-file si definisce la funzione Massima Verosimiglianza per il 
% modello (non lineare) di Carreau-Yasuda:
%
%       eta = eta0*(1 + Abs(lambda*gamma)^a)^(n-1)/a
%
% dove i parametri sono:
%
%   eta0 = viscosit a zero shear
%   lambda = tempo caratteristico
%   n - 1 = pendenza della regione a legge di potenza
%   a = ampiezza della zona di transizione da plateau a shear thinning
%
% mentre:
%
%   eta = viscosit del polimero = y
%   gamma = shear rate = x
%
function L = CarreauYasuda(c)
x = [16.3754, 25.3664, 38.8559, 1.03308, 2.06615, 5.33938, 8.51125, 10.5439, 58.6882, 89.9932, 119.991];
y = [1526.68, 1340.35, 1158.12, 2230.12, 2226.36, 1872.87, 1703.63, 1707.15, 1005.31, 844.508, 758.391];
eta0 = c(1);
lambda = c(2);
a = c(3);
n = c(4);
% Definizione della funzione MV
L = sum((y - eta0*(1 + (abs(lambda)*x).^a).^((n-1)/a)).^2);
% Per calcolare il massimo della MV utilizzando "fminsearch" dobbiamo
% cambiare segno alla funzione MV
L = -L;